/*
 * Copyright (c) 2018, 2020 Oracle and/or its affiliates. All rights reserved.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0, which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the
 * Eclipse Public License v. 2.0 are satisfied: GNU General Public License,
 * version 2 with the GNU Classpath Exception, which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 */

package com.sun.ts.tests.jpa.core.override.joincolumn;

import jakarta.persistence.*;
import java.io.Serializable;

@Entity
public class Hardware implements Serializable {

  @Id
  @Column(name = "ID")
  private Integer id;

  @ManyToOne()
  @JoinColumns({ @JoinColumn(name = "cubedID", referencedColumnName = "id"),
      @JoinColumn(name = "location", referencedColumnName = "location") })
  private Cubicle cubicle;

  @Column(name = "CODE")
  private String salesCode;

  public Hardware() {
  }

  public Cubicle getCubicle() {
    return cubicle;
  }

  public void setCubicle(Cubicle cubicle) {
    this.cubicle = cubicle;
  }

  public Integer getId() {
    return id;
  }

  public void setId(Integer id) {
    this.id = id;
  }

  public int hashCode() {
    int hash = 0;
    hash += (this.getId() != null ? this.getId().hashCode() : 0);
    return hash;
  }

  public boolean equals(Object object) {
    // TODO: Warning - this method won't work in the case the id fields are not
    // set
    if (!(object instanceof Hardware)) {
      return false;
    }
    Hardware other = (Hardware) object;
    if (this.getId() != other.getId()
        && (this.getId() == null || !this.getId().equals(other.getId()))) {
      return false;
    }
    return true;
  }

  public String toString() {
    return "com.sun.ts.tests.jpa.core.override.joincolumn." + "Hardware[id="
        + getId() + "]";
  }

  public String getSalesCode() {
    return salesCode;
  }

  public void setSalesCode(String salesCode) {
    this.salesCode = salesCode;
  }
}
